@@ -2360,6 +2360,14 @@ class Imagen(nn.Module):
 
         # add frame dimension for video
 
+        if self.is_video and exists(inpaint_images):
+            video_frames = inpaint_images.shape[2]
+
+            if inpaint_masks.ndim == 3:
+                inpaint_masks = rearrange(inpaint_masks, 'b h w -> b 1 h w')
+
+            assert inpaint_masks.shape[1] == 1, 'for now, inpainting video can only accept a single mask across frames'
+
         assert not (self.is_video and not exists(video_frames)), 'video_frames must be passed in on sample time if training on video'
 
         all_frame_dims = calc_all_frame_dims(self.temporal_downsample_factor, video_frames)
